@@ -38,14 +38,20 @@ if [ ! -f "${SRC}" ]; then
 			tar -cf - "tcl${TCLVERS}" | gzip -c > "../${SRC}"
 		)
 	else
-		wget -O "${SRC}" "${SRCURL}" || exit 1
+		rm -f "${SRC}.tmp"
+		wget -O "${SRC}.tmp" "${SRCURL}" || exit 1
+		mv "${SRC}.tmp" "${SRC}"
 	fi
 fi
 
 (
 	cd 'build' || exit 1
 
-	gzip -dc "../${SRC}" | tar -xf -
+	if [ ! -d '../buildsrc' ]; then
+		gzip -dc "../${SRC}" | tar -xf -
+	else
+		cp -rp ../buildsrc/* './'
+	fi
 
 	cd "${BUILDDIR}" || exit 1
 	for dir in unix win macosx; do
@@ -56,12 +62,14 @@ fi
 
 		./configure --disable-shared --prefix="${INSTDIR}" ${CONFIGUREEXTRA}
 
-		"${MAKE:-make}" || continue
+		${MAKE:-make} || continue
 
-		"${MAKE:-make}" install
+		${MAKE:-make} install
 
 		mkdir "${OUTDIR}/lib" || exit 1
-		cp -r "${INSTDIR}/lib"/tcl*/ "${OUTDIR}/lib/"
+		cp -r "${INSTDIR}/lib"/* "${OUTDIR}/lib/"
+		rm -rf "${OUTDIR}/lib/pkgconfig"
+		rm -f "${OUTDIR}"/lib/* >/dev/null 2>/dev/null
 
 		break
 	done
